# -*- coding: utf-8 -*-
info = {
    "name": "to",
    "date_order": "DMY",
    "january": [
        "sānuali",
        "sān"
    ],
    "february": [
        "fēpueli",
        "fēp"
    ],
    "march": [
        "ma'asi",
        "ma'a"
    ],
    "april": [
        "'epeleli",
        "'epe"
    ],
    "may": [
        "mē"
    ],
    "june": [
        "sune",
        "sun"
    ],
    "july": [
        "siulai",
        "siu"
    ],
    "august": [
        "'aokosi",
        "'aok"
    ],
    "september": [
        "sepitema",
        "sep"
    ],
    "october": [
        "'okatopa",
        "'oka"
    ],
    "november": [
        "nōvema",
        "nōv"
    ],
    "december": [
        "tīsema",
        "tīs"
    ],
    "monday": [
        "mōnite",
        "mōn"
    ],
    "tuesday": [
        "tūsite",
        "tūs"
    ],
    "wednesday": [
        "pulelulu",
        "pul"
    ],
    "thursday": [
        "tu'apulelulu",
        "tu'a"
    ],
    "friday": [
        "falaite",
        "fal"
    ],
    "saturday": [
        "tokonaki",
        "tok"
    ],
    "sunday": [
        "sāpate",
        "sāp"
    ],
    "am": [
        "hh",
        "am",
        "hengihengi"
    ],
    "pm": [
        "ea",
        "pm",
        "efiafi"
    ],
    "year": [
        "ta'u"
    ],
    "month": [
        "māhina"
    ],
    "week": [
        "uike"
    ],
    "day": [
        "'aho"
    ],
    "hour": [
        "houa"
    ],
    "minute": [
        "miniti"
    ],
    "second": [
        "sekoni"
    ],
    "relative-type": {
        "1 year ago": [
            "ta'u kuo'osi"
        ],
        "0 year ago": [
            "ta'ú ni"
        ],
        "in 1 year": [
            "ta'u kaha'u"
        ],
        "1 month ago": [
            "māhina kuo'osi"
        ],
        "0 month ago": [
            "māhiná ni"
        ],
        "in 1 month": [
            "māhina kaha'u"
        ],
        "1 week ago": [
            "uike kuo'osi"
        ],
        "0 week ago": [
            "uiké ni"
        ],
        "in 1 week": [
            "uike kaha'u"
        ],
        "1 day ago": [
            "'aneafi"
        ],
        "0 day ago": [
            "'ahó ni"
        ],
        "in 1 day": [
            "'apongipongi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "taimí ni"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "'i he ta'u 'e (\\d+)"
        ],
        "\\1 year ago": [
            "ta'u 'e (\\d+) kuo'osi"
        ],
        "in \\1 month": [
            "'i he māhina 'e (\\d+)"
        ],
        "\\1 month ago": [
            "māhina 'e (\\d+) kuo'osi"
        ],
        "in \\1 week": [
            "'i he uike 'e (\\d+)"
        ],
        "\\1 week ago": [
            "uike 'e (\\d+) kuo'osi"
        ],
        "in \\1 day": [
            "'i he 'aho 'e (\\d+)"
        ],
        "\\1 day ago": [
            "'aho 'e (\\d+) kuo'osi"
        ],
        "in \\1 hour": [
            "'i he houa 'e (\\d+)"
        ],
        "\\1 hour ago": [
            "houa 'e (\\d+) kuo'osi"
        ],
        "in \\1 minute": [
            "'i he miniti 'e (\\d+)"
        ],
        "\\1 minute ago": [
            "miniti 'e (\\d+) kuo'osi"
        ],
        "in \\1 second": [
            "'i he sekoni 'e (\\d+)"
        ],
        "\\1 second ago": [
            "sekoni 'e (\\d+) kuo'osi"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "fur",
    "date_order": "DMY",
    "january": [
        "zenâr",
        "zen"
    ],
    "february": [
        "fevrâr",
        "fev"
    ],
    "march": [
        "març",
        "mar"
    ],
    "april": [
        "avrîl",
        "avr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "jugn",
        "jug"
    ],
    "july": [
        "lui"
    ],
    "august": [
        "avost",
        "avo"
    ],
    "september": [
        "setembar",
        "set"
    ],
    "october": [
        "otubar",
        "otu"
    ],
    "november": [
        "novembar",
        "nov"
    ],
    "december": [
        "dicembar",
        "dic"
    ],
    "monday": [
        "lunis",
        "lun"
    ],
    "tuesday": [
        "martars",
        "mar"
    ],
    "wednesday": [
        "miercus",
        "mie"
    ],
    "thursday": [
        "joibe",
        "joi"
    ],
    "friday": [
        "vinars",
        "vin"
    ],
    "saturday": [
        "sabide",
        "sab"
    ],
    "sunday": [
        "domenie",
        "dom"
    ],
    "am": [
        "a"
    ],
    "pm": [
        "p"
    ],
    "year": [
        "an"
    ],
    "month": [
        "mês"
    ],
    "week": [
        "setemane"
    ],
    "day": [
        "dì"
    ],
    "hour": [
        "ore"
    ],
    "minute": [
        "minût"
    ],
    "second": [
        "secont"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "îr"
        ],
        "0 day ago": [
            "vuê"
        ],
        "in 1 day": [
            "doman"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "ca di (\\d+) an",
            "ca di (\\d+) agns"
        ],
        "\\1 year ago": [
            "(\\d+) an indaûr",
            "(\\d+) agns indaûr"
        ],
        "in \\1 month": [
            "ca di (\\d+) mês"
        ],
        "\\1 month ago": [
            "(\\d+) mês indaûr"
        ],
        "in \\1 week": [
            "ca di (\\d+) setemane",
            "ca di (\\d+) setemanis"
        ],
        "\\1 week ago": [
            "(\\d+) setemane indaûr",
            "(\\d+) setemanis indaûr"
        ],
        "in \\1 day": [
            "ca di (\\d+) zornade",
            "ca di (\\d+) zornadis"
        ],
        "\\1 day ago": [
            "(\\d+) zornade indaûr",
            "(\\d+) zornadis indaûr"
        ],
        "in \\1 hour": [
            "ca di (\\d+) ore",
            "ca di (\\d+) oris"
        ],
        "\\1 hour ago": [
            "(\\d+) ore indaûr",
            "(\\d+) oris indaûr"
        ],
        "in \\1 minute": [
            "ca di (\\d+) minût",
            "ca di (\\d+) minûts"
        ],
        "\\1 minute ago": [
            "(\\d+) minût indaûr",
            "(\\d+) minûts indaûr"
        ],
        "in \\1 second": [
            "ca di (\\d+) secont",
            "ca di (\\d+) seconts"
        ],
        "\\1 second ago": [
            "(\\d+) secont indaûr",
            "(\\d+) seconts indaûr"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "gsw",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "märz",
        "mär"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "auguscht",
        "aug"
    ],
    "september": [
        "septämber",
        "sep"
    ],
    "october": [
        "oktoober",
        "okt"
    ],
    "november": [
        "novämber",
        "nov"
    ],
    "december": [
        "dezämber",
        "dez"
    ],
    "monday": [
        "määntig",
        "mä"
    ],
    "tuesday": [
        "ziischtig",
        "zi"
    ],
    "wednesday": [
        "mittwuch",
        "mi"
    ],
    "thursday": [
        "dunschtig",
        "du"
    ],
    "friday": [
        "friitig",
        "fr"
    ],
    "saturday": [
        "samschtig",
        "sa"
    ],
    "sunday": [
        "sunntig",
        "su"
    ],
    "am": [
        "vormittag",
        "vorm",
        "am vormittag"
    ],
    "pm": [
        "namittag",
        "nam",
        "am namittag"
    ],
    "year": [
        "jaar"
    ],
    "month": [
        "monet"
    ],
    "week": [
        "wuche"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "schtund"
    ],
    "minute": [
        "minuute"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "geschter"
        ],
        "0 day ago": [
            "hüt"
        ],
        "in 1 day": [
            "moorn"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {
        "gsw-LI": {
            "name": "gsw-LI"
        },
        "gsw-FR": {
            "name": "gsw-FR"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "chr",
    "date_order": "MDY",
    "january": [
        "ᎤᏃᎸᏔᏅ",
        "ᎤᏃ"
    ],
    "february": [
        "ᎧᎦᎵ",
        "ᎧᎦ"
    ],
    "march": [
        "ᎠᏅᏱ",
        "ᎠᏅ"
    ],
    "april": [
        "ᎧᏬᏂ",
        "ᎧᏬ"
    ],
    "may": [
        "ᎠᏂᏍᎬᏘ",
        "ᎠᏂ"
    ],
    "june": [
        "ᏕᎭᎷᏱ",
        "ᏕᎭ"
    ],
    "july": [
        "ᎫᏰᏉᏂ",
        "ᎫᏰ"
    ],
    "august": [
        "ᎦᎶᏂ",
        "ᎦᎶ"
    ],
    "september": [
        "ᏚᎵᏍᏗ",
        "ᏚᎵ"
    ],
    "october": [
        "ᏚᏂᏅᏗ",
        "ᏚᏂ"
    ],
    "november": [
        "ᏅᏓᏕᏆ",
        "ᏅᏓ"
    ],
    "december": [
        "ᎥᏍᎩᏱ",
        "ᎥᏍ"
    ],
    "monday": [
        "ᎤᎾᏙᏓᏉᏅᎯ",
        "ᏉᏅᎯ"
    ],
    "tuesday": [
        "ᏔᎵᏁᎢᎦ",
        "ᏔᎵᏁ"
    ],
    "wednesday": [
        "ᏦᎢᏁᎢᎦ",
        "ᏦᎢᏁ"
    ],
    "thursday": [
        "ᏅᎩᏁᎢᎦ",
        "ᏅᎩᏁ"
    ],
    "friday": [
        "ᏧᎾᎩᎶᏍᏗ",
        "ᏧᎾᎩ"
    ],
    "saturday": [
        "ᎤᎾᏙᏓᏈᏕᎾ",
        "ᏈᏕᎾ"
    ],
    "sunday": [
        "ᎤᎾᏙᏓᏆᏍᎬ",
        "ᏆᏍᎬ"
    ],
    "am": [
        "ᏌᎾᎴ"
    ],
    "pm": [
        "ᏒᎯᏱᎢᏗᏢ"
    ],
    "year": [
        "ᎤᏕᏘᏴᏌᏗᏒᎢ",
        "ᎤᏕ"
    ],
    "month": [
        "ᎧᎸᎢ",
        "ᎧᎸ"
    ],
    "week": [
        "ᏒᎾᏙᏓᏆᏍᏗ",
        "ᏒᎾ"
    ],
    "day": [
        "ᎢᎦ"
    ],
    "hour": [
        "ᏑᏟᎶᏓ",
        "ᏑᏟ"
    ],
    "minute": [
        "ᎢᏯᏔᏬᏍᏔᏅ",
        "ᎢᏯᏔ"
    ],
    "second": [
        "ᎠᏎᏢ"
    ],
    "relative-type": {
        "1 year ago": [
            "ᎡᏘ ᏥᎨᏒ"
        ],
        "0 year ago": [
            "ᎯᎠ ᏧᏕᏘᏴᏒᏘ"
        ],
        "in 1 year": [
            "ᎡᏘᏴᎢ"
        ],
        "1 month ago": [
            "ᎧᎸᎢ ᏥᎨᏒ"
        ],
        "0 month ago": [
            "ᎯᎠ ᎧᎸᎢ"
        ],
        "in 1 month": [
            "ᏔᎵᏁ ᎧᎸᎢ"
        ],
        "1 week ago": [
            "ᏥᏛᎵᏱᎵᏒᎢ"
        ],
        "0 week ago": [
            "ᎯᎠ ᎠᎵᎵᏌ"
        ],
        "in 1 week": [
            "ᏐᏆᎴᏅᎲ"
        ],
        "1 day ago": [
            "ᏒᎯ"
        ],
        "0 day ago": [
            "ᎪᎯ ᎢᎦ"
        ],
        "in 1 day": [
            "ᏌᎾᎴᎢ"
        ],
        "0 hour ago": [
            "ᎯᎠ ᏑᏟᎶᏓ"
        ],
        "0 minute ago": [
            "ᎯᎠ ᎢᏯᏔᏬᏍᏔᏅ"
        ],
        "0 second ago": [
            "ᏃᏊ"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "ᎾᎿ (\\d+) ᎤᏕᏘᏴᏌᏗᏒᎢ",
            "ᎾᎿ (\\d+) ᎢᏧᏕᏘᏴᏌᏗᏒᎢ",
            "ᎾᎿ (\\d+) ᎤᏕ"
        ],
        "\\1 year ago": [
            "(\\d+) ᎤᏕᏘᏴᏌᏗᏒᎢ ᏥᎨᏒ",
            "(\\d+) ᎢᏧᏕᏘᏴᏌᏗᏒᎢ ᏥᎨᏒ",
            "ᎾᎿ (\\d+) ᎤᏕ ᏥᎨᏒ"
        ],
        "in \\1 month": [
            "ᎾᎿ (\\d+) ᎧᎸᎢ",
            "ᎾᎿ (\\d+) ᏗᎧᎸᎢ",
            "ᎾᎿ (\\d+) ᎧᎸ"
        ],
        "\\1 month ago": [
            "ᎾᎿ (\\d+) ᎧᎸᎢ ᏥᎨᏒ",
            "ᎾᎿ (\\d+) ᏗᎧᎸᎢ ᏥᎨᏒ",
            "ᎾᎿ (\\d+) ᎧᎸ ᏥᎨᏒ"
        ],
        "in \\1 week": [
            "ᎾᎿ (\\d+) ᏒᎾᏙᏓᏆᏍᏗ",
            "ᎾᎿ (\\d+) ᎢᏳᎾᏙᏓᏆᏍᏗ",
            "ᎾᎿ (\\d+) ᏒᎾ"
        ],
        "\\1 week ago": [
            "ᎾᎿ (\\d+) ᏒᎾᏙᏓᏆᏍᏗ ᏥᎨᏒ",
            "ᎾᎿ (\\d+) ᎢᏳᎾᏙᏓᏆᏍᏗ ᏥᎨᏒ",
            "ᎾᎿ (\\d+) ᏒᎾ ᏥᎨᏒ"
        ],
        "in \\1 day": [
            "ᎾᎿ (\\d+) ᎢᎦ",
            "ᎾᎿ (\\d+) ᎯᎸᏍᎩ ᏧᏒᎯᏛ"
        ],
        "\\1 day ago": [
            "(\\d+) ᎢᎦ ᏥᎨᏒ",
            "(\\d+) ᎯᎸᏍᎩ ᏧᏒᎯᏛ ᏥᎨᏒ"
        ],
        "in \\1 hour": [
            "ᎾᎿ (\\d+) ᏑᏟᎶᏓ",
            "ᎾᎿ (\\d+) ᎢᏳᏟᎶᏓ",
            "ᎾᎿ (\\d+) ᏑᏟ"
        ],
        "\\1 hour ago": [
            "(\\d+) ᏑᏟᎶᏓ ᏥᎨᏒ",
            "(\\d+) ᎢᏳᏟᎶᏓ ᏥᎨᏒ",
            "ᎾᎿ (\\d+) ᏑᏟ ᏥᎨᏒ"
        ],
        "in \\1 minute": [
            "ᎾᎿ (\\d+) ᎢᏯᏔᏬᏍᏔᏅ",
            "ᎾᎿ (\\d+) ᎢᏯᏔ"
        ],
        "\\1 minute ago": [
            "ᎾᎿ (\\d+) ᎢᏯᏔᏬᏍᏔᏅ ᏥᎨᏒ",
            "ᎾᎿ (\\d+) ᎢᏯᏔ ᏥᎨᏒ"
        ],
        "in \\1 second": [
            "ᎾᎿ (\\d+) ᎠᏎᏢ",
            "ᎾᎿ (\\d+) ᏓᏓᎾᏩᏍᎬ ᏥᎨᏒ"
        ],
        "\\1 second ago": [
            "(\\d+) ᎠᏎᏢ ᏥᎨᏒ",
            "(\\d+) ᏓᏓᎾᏩᏍᎬ ᏥᎨᏒ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ur",
    "date_order": "DMY",
    "january": [
        "جنوری"
    ],
    "february": [
        "فروری"
    ],
    "march": [
        "مارچ"
    ],
    "april": [
        "اپریل"
    ],
    "may": [
        "مئی"
    ],
    "june": [
        "جون"
    ],
    "july": [
        "جولائی"
    ],
    "august": [
        "اگست"
    ],
    "september": [
        "ستمبر"
    ],
    "october": [
        "اکتوبر"
    ],
    "november": [
        "نومبر"
    ],
    "december": [
        "دسمبر"
    ],
    "monday": [
        "سوموار"
    ],
    "tuesday": [
        "منگل"
    ],
    "wednesday": [
        "بدھ"
    ],
    "thursday": [
        "جمعرات"
    ],
    "friday": [
        "جمعہ"
    ],
    "saturday": [
        "ہفتہ"
    ],
    "sunday": [
        "اتوار"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "سال"
    ],
    "month": [
        "مہینہ",
        "ماہ"
    ],
    "week": [
        "ہفتہ"
    ],
    "day": [
        "دن"
    ],
    "hour": [
        "گھنٹہ"
    ],
    "minute": [
        "منٹ"
    ],
    "second": [
        "سیکنڈ"
    ],
    "relative-type": {
        "1 year ago": [
            "گزشتہ سال"
        ],
        "0 year ago": [
            "اس سال"
        ],
        "in 1 year": [
            "اگلے سال"
        ],
        "1 month ago": [
            "پچھلے مہینہ"
        ],
        "0 month ago": [
            "اس مہینہ"
        ],
        "in 1 month": [
            "اگلے مہینہ"
        ],
        "1 week ago": [
            "پچھلے ہفتہ"
        ],
        "0 week ago": [
            "اس ہفتہ"
        ],
        "in 1 week": [
            "اگلے ہفتہ"
        ],
        "1 day ago": [
            "گزشتہ کل"
        ],
        "0 day ago": [
            "آج"
        ],
        "in 1 day": [
            "آئندہ کل"
        ],
        "0 hour ago": [
            "اس گھنٹے"
        ],
        "0 minute ago": [
            "اس منٹ"
        ],
        "0 second ago": [
            "اب"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) سال میں"
        ],
        "\\1 year ago": [
            "(\\d+) سال پہلے"
        ],
        "in \\1 month": [
            "(\\d+) مہینہ میں",
            "(\\d+) مہینے میں",
            "(\\d+) ماہ میں"
        ],
        "\\1 month ago": [
            "(\\d+) مہینہ پہلے",
            "(\\d+) مہینے پہلے",
            "(\\d+) ماہ قبل",
            "(\\d+) ماہ پہلے"
        ],
        "in \\1 week": [
            "(\\d+) ہفتہ میں",
            "(\\d+) ہفتے میں"
        ],
        "\\1 week ago": [
            "(\\d+) ہفتہ پہلے",
            "(\\d+) ہفتے پہلے"
        ],
        "in \\1 day": [
            "(\\d+) دن میں",
            "(\\d+) دنوں میں"
        ],
        "\\1 day ago": [
            "(\\d+) دن پہلے",
            "(\\d+) دنوں پہلے"
        ],
        "in \\1 hour": [
            "(\\d+) گھنٹہ میں",
            "(\\d+) گھنٹے میں",
            "(\\d+) گھنٹوں میں"
        ],
        "\\1 hour ago": [
            "(\\d+) گھنٹہ پہلے",
            "(\\d+) گھنٹے پہلے"
        ],
        "in \\1 minute": [
            "(\\d+) منٹ میں"
        ],
        "\\1 minute ago": [
            "(\\d+) منٹ پہلے"
        ],
        "in \\1 second": [
            "(\\d+) سیکنڈ میں"
        ],
        "\\1 second ago": [
            "(\\d+) سیکنڈ پہلے"
        ]
    },
    "locale_specific": {
        "ur-IN": {
            "name": "ur-IN",
            "monday": [
                "پیر"
            ],
            "relative-type": {
                "1 month ago": [
                    "گزشتہ ماہ"
                ],
                "0 month ago": [
                    "اس ماہ"
                ],
                "in 1 month": [
                    "اگلے ماہ"
                ],
                "1 week ago": [
                    "گزشتہ ہفتہ"
                ]
            },
            "relative-type-regex": {
                "in \\1 year": [
                    "(\\d+) سالوں میں"
                ],
                "\\1 year ago": [
                    "(\\d+) سالوں پہلے"
                ],
                "in \\1 week": [
                    "(\\d+) ہفتوں میں"
                ],
                "\\1 week ago": [
                    "(\\d+) ہفتہ قبل",
                    "(\\d+) ہفتے قبل"
                ],
                "\\1 day ago": [
                    "(\\d+) دن قبل"
                ],
                "\\1 hour ago": [
                    "(\\d+) گھنٹہ قبل",
                    "(\\d+) گھنٹے قبل"
                ],
                "\\1 minute ago": [
                    "(\\d+) منٹ قبل"
                ],
                "\\1 second ago": [
                    "(\\d+) سیکنڈ قبل"
                ]
            }
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "hr",
    "date_order": "DMY",
    "january": [
        "siječanj",
        "sij",
        "siječnja"
    ],
    "february": [
        "veljača",
        "velj",
        "veljače"
    ],
    "march": [
        "ožujak",
        "ožu",
        "ožujka"
    ],
    "april": [
        "travanj",
        "tra",
        "travnja"
    ],
    "may": [
        "svibanj",
        "svi",
        "svibnja"
    ],
    "june": [
        "lipanj",
        "lip",
        "lipnja"
    ],
    "july": [
        "srpanj",
        "srp",
        "srpnja"
    ],
    "august": [
        "kolovoz",
        "kol",
        "kolovoza"
    ],
    "september": [
        "rujan",
        "ruj",
        "rujna"
    ],
    "october": [
        "listopad",
        "lis",
        "listopada"
    ],
    "november": [
        "studeni",
        "stu",
        "studenoga"
    ],
    "december": [
        "prosinac",
        "pro",
        "prosinca"
    ],
    "monday": [
        "ponedjeljak",
        "pon"
    ],
    "tuesday": [
        "utorak",
        "uto"
    ],
    "wednesday": [
        "srijeda",
        "sri"
    ],
    "thursday": [
        "četvrtak",
        "čet"
    ],
    "friday": [
        "petak",
        "pet"
    ],
    "saturday": [
        "subota",
        "sub"
    ],
    "sunday": [
        "nedjelja",
        "ned"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "godina",
        "g"
    ],
    "month": [
        "mjesec",
        "mj",
        "m"
    ],
    "week": [
        "tjedan",
        "tj"
    ],
    "day": [
        "dan",
        "d"
    ],
    "hour": [
        "sat",
        "h"
    ],
    "minute": [
        "minuta",
        "min"
    ],
    "second": [
        "sekunda",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "prošle godine",
            "prošle god",
            "prošle g"
        ],
        "0 year ago": [
            "ove godine",
            "ove god",
            "ove g"
        ],
        "in 1 year": [
            "sljedeće godine",
            "sljedeće god",
            "sljedeće g"
        ],
        "1 month ago": [
            "prošli mjesec",
            "prošli mj"
        ],
        "0 month ago": [
            "ovaj mjesec",
            "ovaj mj"
        ],
        "in 1 month": [
            "sljedeći mjesec",
            "sljedeći mj"
        ],
        "1 week ago": [
            "prošli tjedan",
            "prošli tj"
        ],
        "0 week ago": [
            "ovaj tjedan",
            "ovaj tj"
        ],
        "in 1 week": [
            "sljedeći tjedan",
            "sljedeći tj"
        ],
        "1 day ago": [
            "jučer"
        ],
        "0 day ago": [
            "danas"
        ],
        "in 1 day": [
            "sutra"
        ],
        "0 hour ago": [
            "ovaj sat"
        ],
        "0 minute ago": [
            "ova minuta"
        ],
        "0 second ago": [
            "sad"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) godinu",
            "za (\\d+) godina",
            "za (\\d+) g"
        ],
        "\\1 year ago": [
            "prije (\\d+) godinu",
            "prije (\\d+) godina",
            "prije (\\d+) g"
        ],
        "in \\1 month": [
            "za (\\d+) mjesec",
            "za (\\d+) mjeseci",
            "za (\\d+) mj"
        ],
        "\\1 month ago": [
            "prije (\\d+) mjesec",
            "prije (\\d+) mjeseci",
            "prije (\\d+) mj"
        ],
        "in \\1 week": [
            "za (\\d+) tjedan",
            "za (\\d+) tjedana",
            "za (\\d+) tj"
        ],
        "\\1 week ago": [
            "prije (\\d+) tjedan",
            "prije (\\d+) tjedana",
            "prije (\\d+) tj"
        ],
        "in \\1 day": [
            "za (\\d+) dan",
            "za (\\d+) dana",
            "za (\\d+) d"
        ],
        "\\1 day ago": [
            "prije (\\d+) dan",
            "prije (\\d+) dana",
            "prije (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) sat",
            "za (\\d+) sati",
            "za (\\d+) h"
        ],
        "\\1 hour ago": [
            "prije (\\d+) sat",
            "prije (\\d+) sati",
            "prije (\\d+) h"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minuta",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "prije (\\d+) minutu",
            "prije (\\d+) minuta",
            "prije (\\d+) min"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundi",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "prije (\\d+) sekundu",
            "prije (\\d+) sekundi",
            "prije (\\d+) s"
        ]
    },
    "locale_specific": {
        "hr-BA": {
            "name": "hr-BA"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "nmg",
    "date_order": "DMY",
    "january": [
        "ngwɛn matáhra",
        "ng1"
    ],
    "february": [
        "ngwɛn ńmba",
        "ng2"
    ],
    "march": [
        "ngwɛn ńlal",
        "ng3"
    ],
    "april": [
        "ngwɛn ńna",
        "ng4"
    ],
    "may": [
        "ngwɛn ńtan",
        "ng5"
    ],
    "june": [
        "ngwɛn ńtuó",
        "ng6"
    ],
    "july": [
        "ngwɛn hɛmbuɛrí",
        "ng7"
    ],
    "august": [
        "ngwɛn lɔmbi",
        "ng8"
    ],
    "september": [
        "ngwɛn rɛbvuâ",
        "ng9"
    ],
    "october": [
        "ngwɛn wum",
        "ng10"
    ],
    "november": [
        "ngwɛn wum navǔr",
        "ng11"
    ],
    "december": [
        "krísimin",
        "kris"
    ],
    "monday": [
        "mɔ́ndɔ",
        "mɔ́n"
    ],
    "tuesday": [
        "sɔ́ndɔ mafú mába",
        "smb"
    ],
    "wednesday": [
        "sɔ́ndɔ mafú málal",
        "sml"
    ],
    "thursday": [
        "sɔ́ndɔ mafú mána",
        "smn"
    ],
    "friday": [
        "mabágá má sukul",
        "mbs"
    ],
    "saturday": [
        "sásadi",
        "sas"
    ],
    "sunday": [
        "sɔ́ndɔ",
        "sɔ́n"
    ],
    "am": [
        "maná"
    ],
    "pm": [
        "kugú"
    ],
    "year": [
        "mbvu"
    ],
    "month": [
        "ngwɛn"
    ],
    "week": [
        "sɔ́ndɔ"
    ],
    "day": [
        "duö"
    ],
    "hour": [
        "wulā"
    ],
    "minute": [
        "mpálâ"
    ],
    "second": [
        "nyiɛl"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nakugú"
        ],
        "0 day ago": [
            "dɔl"
        ],
        "in 1 day": [
            "namáná"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ky",
    "date_order": "DMY",
    "january": [
        "январь",
        "янв"
    ],
    "february": [
        "февраль",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "апрель",
        "апр"
    ],
    "may": [
        "май"
    ],
    "june": [
        "июнь",
        "июн"
    ],
    "july": [
        "июль",
        "июл"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "сентябрь",
        "сен"
    ],
    "october": [
        "октябрь",
        "окт"
    ],
    "november": [
        "ноябрь",
        "ноя"
    ],
    "december": [
        "декабрь",
        "дек"
    ],
    "monday": [
        "дүйшөмбү",
        "дүй"
    ],
    "tuesday": [
        "шейшемби",
        "шейш"
    ],
    "wednesday": [
        "шаршемби",
        "шарш"
    ],
    "thursday": [
        "бейшемби",
        "бейш"
    ],
    "friday": [
        "жума"
    ],
    "saturday": [
        "ишемби",
        "ишм"
    ],
    "sunday": [
        "жекшемби",
        "жек"
    ],
    "am": [
        "таңкы",
        "тң"
    ],
    "pm": [
        "түштөн кийинки",
        "тк"
    ],
    "year": [
        "жыл",
        "ж"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "апта",
        "апт"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "саат",
        "ст"
    ],
    "minute": [
        "мүнөт",
        "мүн",
        "м"
    ],
    "second": [
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "былтыр"
        ],
        "0 year ago": [
            "быйыл"
        ],
        "in 1 year": [
            "эмдиги жылы"
        ],
        "1 month ago": [
            "өткөн айда"
        ],
        "0 month ago": [
            "бул айда"
        ],
        "in 1 month": [
            "эмдиги айда"
        ],
        "1 week ago": [
            "өткөн аптада",
            "өткөн апт"
        ],
        "0 week ago": [
            "ушул аптада",
            "ушул апт"
        ],
        "in 1 week": [
            "келерки аптада",
            "келерки апт"
        ],
        "1 day ago": [
            "кечээ"
        ],
        "0 day ago": [
            "бүгүн"
        ],
        "in 1 day": [
            "эртеӊ"
        ],
        "0 hour ago": [
            "ушул саатта"
        ],
        "0 minute ago": [
            "ушул мүнөттө"
        ],
        "0 second ago": [
            "азыр"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жылдан кийин",
            "(\\d+) жыл кийин"
        ],
        "\\1 year ago": [
            "(\\d+) жыл мурун"
        ],
        "in \\1 month": [
            "(\\d+) айдан кийин",
            "(\\d+) айд кийин",
            "(\\d+) айд кийн"
        ],
        "\\1 month ago": [
            "(\\d+) ай мурун",
            "(\\d+) ай мурн"
        ],
        "in \\1 week": [
            "(\\d+) аптадан кийин",
            "(\\d+) апт кийин"
        ],
        "\\1 week ago": [
            "(\\d+) апта мурун",
            "(\\d+) апт мурун"
        ],
        "in \\1 day": [
            "(\\d+) күндөн кийин",
            "(\\d+) күн кийин"
        ],
        "\\1 day ago": [
            "(\\d+) күн мурун"
        ],
        "in \\1 hour": [
            "(\\d+) сааттан кийин",
            "(\\d+) саат кийин",
            "(\\d+) с кийн"
        ],
        "\\1 hour ago": [
            "(\\d+) саат мурун",
            "(\\d+) с мурн"
        ],
        "in \\1 minute": [
            "(\\d+) мүнөттөн кийин",
            "(\\d+) мүн кийин",
            "(\\d+) мүн кийн"
        ],
        "\\1 minute ago": [
            "(\\d+) мүнөт мурун",
            "(\\d+) мүн мурун",
            "(\\d+) мүн мурн"
        ],
        "in \\1 second": [
            "(\\d+) секунддан кийин",
            "(\\d+) сек кийин",
            "(\\d+) сек кийн"
        ],
        "\\1 second ago": [
            "(\\d+) секунд мурун",
            "(\\d+) сек мурун",
            "(\\d+) сек мурн"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "cs",
    "date_order": "DMY",
    "january": [
        "leden",
        "led",
        "ledna"
    ],
    "february": [
        "únor",
        "úno",
        "února"
    ],
    "march": [
        "březen",
        "bře",
        "března"
    ],
    "april": [
        "duben",
        "dub",
        "dubna"
    ],
    "may": [
        "květen",
        "kvě",
        "května"
    ],
    "june": [
        "červen",
        "čvn",
        "června",
        "Čer"
    ],
    "july": [
        "červenec",
        "čvc",
        "července",
        "Črc"
    ],
    "august": [
        "srpen",
        "srp",
        "srpna"
    ],
    "september": [
        "září",
        "zář"
    ],
    "october": [
        "říjen",
        "říj",
        "října"
    ],
    "november": [
        "listopad",
        "lis",
        "listopadu"
    ],
    "december": [
        "prosinec",
        "pro",
        "prosince"
    ],
    "monday": [
        "pondělí",
        "po",
        "Pon"
    ],
    "tuesday": [
        "úterý",
        "út",
        "Úte"
    ],
    "wednesday": [
        "středa",
        "st",
        "Stř",
        "Středu"
    ],
    "thursday": [
        "čtvrtek",
        "čt",
        "Čtv"
    ],
    "friday": [
        "pátek",
        "pá",
        "Pát"
    ],
    "saturday": [
        "sobota",
        "so",
        "Sob",
        "Sobotu"
    ],
    "sunday": [
        "neděle",
        "ne",
        "Ned",
        "Neděli"
    ],
    "am": [
        "dop"
    ],
    "pm": [
        "odp"
    ],
    "year": [
        "rok",
        "r",
        "roků",
        "roky"
    ],
    "month": [
        "měsíc",
        "měs",
        "měsíců",
        "měsíce"
    ],
    "week": [
        "týden",
        "týd",
        "týdnů",
        "týdny"
    ],
    "day": [
        "den",
        "dnů",
        "dny"
    ],
    "hour": [
        "hodina",
        "h",
        "hodin",
        "hodiny",
        "hodinu",
        "hodinami"
    ],
    "minute": [
        "minuta",
        "min",
        "minut",
        "minuty"
    ],
    "second": [
        "sekunda",
        "s",
        "sekundy",
        "sekund",
        "vteřina",
        "vteřin",
        "vteřiny"
    ],
    "relative-type": {
        "1 year ago": [
            "minulý rok"
        ],
        "0 year ago": [
            "tento rok"
        ],
        "in 1 year": [
            "příští rok"
        ],
        "1 month ago": [
            "minulý měsíc"
        ],
        "0 month ago": [
            "tento měsíc"
        ],
        "in 1 month": [
            "příští měsíc"
        ],
        "1 week ago": [
            "minulý týden",
            "minulý týd"
        ],
        "0 week ago": [
            "tento týden",
            "tento týd"
        ],
        "in 1 week": [
            "příští týden",
            "příští týd"
        ],
        "1 day ago": [
            "včera"
        ],
        "0 day ago": [
            "dnes"
        ],
        "in 1 day": [
            "zítra"
        ],
        "0 hour ago": [
            "tuto hodinu"
        ],
        "0 minute ago": [
            "tuto minutu"
        ],
        "0 second ago": [
            "nyní"
        ],
        "2 day ago": [
            "předevčírem"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) rok",
            "za (\\d+) let",
            "za (\\d+) r",
            "za (\\d+) l"
        ],
        "\\1 year ago": [
            "před (\\d+) rokem",
            "před (\\d+) lety",
            "před (\\d+) r",
            "před (\\d+) l"
        ],
        "in \\1 month": [
            "za (\\d+) měsíc",
            "za (\\d+) měsíců",
            "za (\\d+) měs"
        ],
        "\\1 month ago": [
            "před (\\d+) měsícem",
            "před (\\d+) měsíci",
            "před (\\d+) měs"
        ],
        "in \\1 week": [
            "za (\\d+) týden",
            "za (\\d+) týdnů",
            "za (\\d+) týd"
        ],
        "\\1 week ago": [
            "před (\\d+) týdnem",
            "před (\\d+) týdny",
            "před (\\d+) týd"
        ],
        "in \\1 day": [
            "za (\\d+) den",
            "za (\\d+) dní"
        ],
        "\\1 day ago": [
            "před (\\d+) dnem",
            "před (\\d+) dny"
        ],
        "in \\1 hour": [
            "za (\\d+) hodinu",
            "za (\\d+) hodin",
            "za (\\d+) h"
        ],
        "\\1 hour ago": [
            "před (\\d+) hodinou",
            "před (\\d+) hodinami",
            "před (\\d+) h"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minut",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "před (\\d+) minutou",
            "před (\\d+) minutami",
            "před (\\d+) min"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekund",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "před (\\d+) sekundou",
            "před (\\d+) sekundami",
            "před (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        "přibližně",
        "v",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "před"
    ],
    "in": [
        "ve",
        "v"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ak",
    "date_order": "YMD",
    "january": [
        "sanda-ɔpɛpɔn",
        "s-ɔ"
    ],
    "february": [
        "kwakwar-ɔgyefuo",
        "k-ɔ"
    ],
    "march": [
        "ebɔw-ɔbenem",
        "e-ɔ"
    ],
    "april": [
        "ebɔbira-oforisuo",
        "e-o"
    ],
    "may": [
        "esusow aketseaba-kɔtɔnimba",
        "e-k"
    ],
    "june": [
        "obirade-ayɛwohomumu",
        "o-a"
    ],
    "july": [
        "ayɛwoho-kitawonsa",
        "a-k"
    ],
    "august": [
        "difuu-ɔsandaa",
        "d-ɔ"
    ],
    "september": [
        "fankwa-ɛbɔ",
        "f-ɛ"
    ],
    "october": [
        "ɔbɛsɛ-ahinime",
        "ɔ-a"
    ],
    "november": [
        "ɔberɛfɛw-obubuo",
        "ɔ-o"
    ],
    "december": [
        "mumu-ɔpɛnimba",
        "m-ɔ"
    ],
    "monday": [
        "dwowda",
        "dwo"
    ],
    "tuesday": [
        "benada",
        "ben"
    ],
    "wednesday": [
        "wukuda",
        "wuk"
    ],
    "thursday": [
        "yawda",
        "yaw"
    ],
    "friday": [
        "fida",
        "fia"
    ],
    "saturday": [
        "memeneda",
        "mem"
    ],
    "sunday": [
        "kwesida",
        "kwe"
    ],
    "am": [
        "an"
    ],
    "pm": [
        "ew"
    ],
    "year": [
        "afe"
    ],
    "month": [
        "bosome"
    ],
    "week": [
        "dapɛn"
    ],
    "day": [
        "da"
    ],
    "hour": [
        "dɔnhwer"
    ],
    "minute": [
        "sema"
    ],
    "second": [
        "sɛkɛnd"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ndeda"
        ],
        "0 day ago": [
            "ndɛ"
        ],
        "in 1 day": [
            "ɔkyena"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "et",
    "date_order": "DMY",
    "january": [
        "jaanuar",
        "jaan"
    ],
    "february": [
        "veebruar",
        "veebr"
    ],
    "march": [
        "märts"
    ],
    "april": [
        "aprill",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juuni"
    ],
    "july": [
        "juuli"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sept"
    ],
    "october": [
        "oktoober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "detsember",
        "dets"
    ],
    "monday": [
        "esmaspäev",
        "e"
    ],
    "tuesday": [
        "teisipäev",
        "t"
    ],
    "wednesday": [
        "kolmapäev",
        "k"
    ],
    "thursday": [
        "neljapäev",
        "n"
    ],
    "friday": [
        "reede",
        "r"
    ],
    "saturday": [
        "laupäev",
        "l"
    ],
    "sunday": [
        "pühapäev",
        "p"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "aasta",
        "a"
    ],
    "month": [
        "kuu",
        "k"
    ],
    "week": [
        "nädal",
        "näd"
    ],
    "day": [
        "päev",
        "p"
    ],
    "hour": [
        "tund",
        "t"
    ],
    "minute": [
        "minut",
        "min"
    ],
    "second": [
        "sekund",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "eelmine aasta"
        ],
        "0 year ago": [
            "käesolev aasta"
        ],
        "in 1 year": [
            "järgmine aasta"
        ],
        "1 month ago": [
            "eelmine kuu"
        ],
        "0 month ago": [
            "käesolev kuu"
        ],
        "in 1 month": [
            "järgmine kuu"
        ],
        "1 week ago": [
            "eelmine nädal"
        ],
        "0 week ago": [
            "käesolev nädal"
        ],
        "in 1 week": [
            "järgmine nädal"
        ],
        "1 day ago": [
            "eile"
        ],
        "0 day ago": [
            "täna"
        ],
        "in 1 day": [
            "homme"
        ],
        "0 hour ago": [
            "praegusel tunnil"
        ],
        "0 minute ago": [
            "praegusel minutil"
        ],
        "0 second ago": [
            "nüüd"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) aasta pärast",
            "(\\d+) a pärast"
        ],
        "\\1 year ago": [
            "(\\d+) aasta eest",
            "(\\d+) a eest"
        ],
        "in \\1 month": [
            "(\\d+) kuu pärast",
            "(\\d+) k pärast"
        ],
        "\\1 month ago": [
            "(\\d+) kuu eest",
            "(\\d+) k eest"
        ],
        "in \\1 week": [
            "(\\d+) nädala pärast",
            "(\\d+) näd pärast"
        ],
        "\\1 week ago": [
            "(\\d+) nädala eest",
            "(\\d+) näd eest"
        ],
        "in \\1 day": [
            "(\\d+) päeva pärast",
            "(\\d+) p pärast"
        ],
        "\\1 day ago": [
            "(\\d+) päeva eest",
            "(\\d+) p eest"
        ],
        "in \\1 hour": [
            "(\\d+) tunni pärast",
            "(\\d+) t pärast"
        ],
        "\\1 hour ago": [
            "(\\d+) tunni eest",
            "(\\d+) t eest"
        ],
        "in \\1 minute": [
            "(\\d+) minuti pärast",
            "(\\d+) min pärast"
        ],
        "\\1 minute ago": [
            "(\\d+) minuti eest",
            "(\\d+) min eest"
        ],
        "in \\1 second": [
            "(\\d+) sekundi pärast",
            "(\\d+) sek pärast",
            "(\\d+) s pärast"
        ],
        "\\1 second ago": [
            "(\\d+) sekundi eest",
            "(\\d+) sek eest",
            "(\\d+) s eest"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "nn",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "måndag",
        "mån",
        "må"
    ],
    "tuesday": [
        "tysdag",
        "tys",
        "ty"
    ],
    "wednesday": [
        "onsdag",
        "ons",
        "on"
    ],
    "thursday": [
        "torsdag",
        "tor",
        "to"
    ],
    "friday": [
        "fredag",
        "fre",
        "fr"
    ],
    "saturday": [
        "laurdag",
        "lau",
        "la"
    ],
    "sunday": [
        "søndag",
        "søn",
        "sø"
    ],
    "am": [
        "fm",
        "formiddag"
    ],
    "pm": [
        "em",
        "ettermiddag"
    ],
    "year": [
        "år"
    ],
    "month": [
        "månad"
    ],
    "week": [
        "veke"
    ],
    "day": [
        "dag"
    ],
    "hour": [
        "time"
    ],
    "minute": [
        "minutt"
    ],
    "second": [
        "sekund"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "i går"
        ],
        "0 day ago": [
            "i dag"
        ],
        "in 1 day": [
            "i morgon"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) år"
        ],
        "\\1 year ago": [
            "for (\\d+) år siden"
        ],
        "in \\1 month": [
            "om (\\d+) måned",
            "om (\\d+) måneder"
        ],
        "\\1 month ago": [
            "for (\\d+) måned siden",
            "for (\\d+) måneder siden"
        ],
        "in \\1 week": [
            "om (\\d+) uke",
            "om (\\d+) uker"
        ],
        "\\1 week ago": [
            "for (\\d+) uke siden",
            "for (\\d+) uker siden"
        ],
        "in \\1 day": [
            "om (\\d+) døgn"
        ],
        "\\1 day ago": [
            "for (\\d+) døgn siden"
        ],
        "in \\1 hour": [
            "om (\\d+) time",
            "om (\\d+) timer"
        ],
        "\\1 hour ago": [
            "for (\\d+) time siden",
            "for (\\d+) timer siden"
        ],
        "in \\1 minute": [
            "om (\\d+) minutt",
            "om (\\d+) minutter"
        ],
        "\\1 minute ago": [
            "for (\\d+) minutt siden",
            "for (\\d+) minutter siden"
        ],
        "in \\1 second": [
            "om (\\d+) sekund",
            "om (\\d+) sekunder"
        ],
        "\\1 second ago": [
            "for (\\d+) sekund siden",
            "for (\\d+) sekunder siden"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ewo",
    "date_order": "DMY",
    "january": [
        "ngɔn osú",
        "ngo"
    ],
    "february": [
        "ngɔn bɛ̌",
        "ngb"
    ],
    "march": [
        "ngɔn lála",
        "ngl"
    ],
    "april": [
        "ngɔn nyina",
        "ngn"
    ],
    "may": [
        "ngɔn tána",
        "ngt"
    ],
    "june": [
        "ngɔn saməna",
        "ngs"
    ],
    "july": [
        "ngɔn zamgbála",
        "ngz"
    ],
    "august": [
        "ngɔn mwom",
        "ngm"
    ],
    "september": [
        "ngɔn ebulú",
        "nge"
    ],
    "october": [
        "ngɔn awóm",
        "nga"
    ],
    "november": [
        "ngɔn awóm ai dziá",
        "ngad"
    ],
    "december": [
        "ngɔn awóm ai bɛ̌",
        "ngab"
    ],
    "monday": [
        "mɔ́ndi",
        "mɔ́n"
    ],
    "tuesday": [
        "sɔ́ndɔ məlú mə́bɛ̌",
        "smb"
    ],
    "wednesday": [
        "sɔ́ndɔ məlú mə́lɛ́",
        "sml"
    ],
    "thursday": [
        "sɔ́ndɔ məlú mə́nyi",
        "smn"
    ],
    "friday": [
        "fúladé",
        "fúl"
    ],
    "saturday": [
        "séradé",
        "sér"
    ],
    "sunday": [
        "sɔ́ndɔ",
        "sɔ́n"
    ],
    "am": [
        "kíkíríg"
    ],
    "pm": [
        "ngəgógəle"
    ],
    "year": [
        "m̀bú"
    ],
    "month": [
        "ngɔn"
    ],
    "week": [
        "sɔ́ndɔ"
    ],
    "day": [
        "amǒs"
    ],
    "hour": [
        "awola"
    ],
    "minute": [
        "enútɛn"
    ],
    "second": [
        "akábəga"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "angogé"
        ],
        "0 day ago": [
            "aná"
        ],
        "in 1 day": [
            "okírí"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
from collections import OrderedDict
from git import Repo
import os


def get_raw_data():
    cldr_dates_full_url = "https://github.com/unicode-cldr/cldr-dates-full.git"
    cldr_core_url = "https://github.com/unicode-cldr/cldr-core.git"
    cldr_rbnf_url = "https://github.com/unicode-cldr/cldr-rbnf.git"
    raw_data_directory = "../raw_data"
    cldr_dates_full_dir = "../raw_data/cldr_dates_full/"
    cldr_core_dir = "../raw_data/cldr_core/"
    cldr_rbnf_dir = "../raw_data/cldr_rbnf/"
    if not os.path.isdir(raw_data_directory):
        os.mkdir(raw_data_directory)
        Repo.clone_from(cldr_dates_full_url, cldr_dates_full_dir, branch='master')
        Repo.clone_from(cldr_core_url, cldr_core_dir, branch='master')
        Repo.clone_from(cldr_rbnf_url, cldr_rbnf_dir, branch='master')


def get_dict_difference(parent_dict, child_dict):
    difference_dict = OrderedDict()
    for key, child_value in child_dict.items():
        parent_value = parent_dict.get(key)
        child_specific_value = None
        if not parent_value:
            child_specific_value = child_value
        elif isinstance(child_value, list):
            child_specific_value = list(set(child_value)-set(parent_value))
        elif isinstance(child_value, dict):
            child_specific_value = get_dict_difference(parent_value, child_value)
        elif child_value != parent_value:
            child_specific_value = child_value
        if child_specific_value:
            difference_dict[key] = child_specific_value
    return difference_dict


def combine_dicts(primary_dict, supplementary_dict):
    combined_dict = OrderedDict()
    for key, value in primary_dict.items():
        if key in supplementary_dict:
            if isinstance(value, list):
                combined_dict[key] = value + supplementary_dict[key]
            elif isinstance(value, dict):
                combined_dict[key] = combine_dicts(value, supplementary_dict[key])
            else:
                combined_dict[key] = supplementary_dict[key]
        else:
            combined_dict[key] = primary_dict[key]
    remaining_keys = [key for key in supplementary_dict.keys() if key not in primary_dict.keys()]
    for key in remaining_keys:
        combined_dict[key] = supplementary_dict[key]
    return combined_dict



# -*- coding: utf-8 -*-
import regex as re
import json
import os
import shutil
from collections import OrderedDict

from dateparser_scripts.utils import get_raw_data

DIGIT_PATTERN = re.compile(r'^\d*$')

os.chdir(os.path.dirname(os.path.abspath(__file__)))
get_raw_data()

cldr_rbnf_dir = "../raw_data/cldr_rbnf/rbnf/"


def _get_numeral_data(language):
    with open(cldr_rbnf_dir + language + '.json') as f:
        cldr_rbnf_data = json.load(f)
    spellout_dict = cldr_rbnf_data["rbnf"]["rbnf"].get("SpelloutRules")
    numeral_dict = OrderedDict()

    if spellout_dict:
        spellout_keys = sorted(spellout_dict.keys())
        for spellout_key in spellout_keys:
            spellout_key_dict = spellout_dict[spellout_key]
            num_keys = sorted([int(key) for key in spellout_key_dict.keys()
                              if DIGIT_PATTERN.match(key)])
            numeral_dict[spellout_key] = OrderedDict()
            for i in range(0, len(num_keys)-1):
                if num_keys[i+1] == num_keys[i] + 1:
                    numeral_dict[spellout_key][str(num_keys[i])] = spellout_key_dict[str(num_keys[i])]
                else:
                    num_range = (num_keys[i], num_keys[i+1]-1)
                    numeral_dict[spellout_key][str(num_range)] = spellout_key_dict[str(num_keys[i])]
            numeral_dict[spellout_key][str((num_keys[len(num_keys)-1], "inf"))] = spellout_key_dict[
                str(num_keys[len(num_keys)-1])]

    return numeral_dict


def main():
    parent_directory = "../dateparser_data/cldr_language_data"
    directory = "../dateparser_data/cldr_language_data/numeral_translation_data/"
    if not os.path.isdir(parent_directory):
        os.mkdir(parent_directory)
    if os.path.isdir(directory):
        shutil.rmtree(directory)
    os.mkdir(directory)

    rbnf_languages = [filename[:-5] for filename in os.listdir(cldr_rbnf_dir)]

    for language in rbnf_languages:
        numeral_dict = _get_numeral_data(language)
        if numeral_dict:
            filename = directory + language + ".json"
            print("writing " + filename)
            json_string = json.dumps(numeral_dict, indent=4, separators=(',', ': '),
                                     ensure_ascii=False).encode('utf-8')
            with open(filename, 'wb') as f:
                f.write(json_string)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
info = {
    "name": "sbp",
    "date_order": "DMY",
    "january": [
        "mupalangulwa",
        "mup"
    ],
    "february": [
        "mwitope",
        "mwi"
    ],
    "march": [
        "mushende",
        "msh"
    ],
    "april": [
        "munyi",
        "mun"
    ],
    "may": [
        "mushende magali",
        "mag"
    ],
    "june": [
        "mujimbi",
        "muj"
    ],
    "july": [
        "mushipepo",
        "msp"
    ],
    "august": [
        "mupuguto",
        "mpg"
    ],
    "september": [
        "munyense",
        "mye"
    ],
    "october": [
        "mokhu",
        "mok"
    ],
    "november": [
        "musongandembwe",
        "mus"
    ],
    "december": [
        "muhaano",
        "muh"
    ],
    "monday": [
        "jumatatu",
        "jtt"
    ],
    "tuesday": [
        "jumanne",
        "jnn"
    ],
    "wednesday": [
        "jumatano",
        "jtn"
    ],
    "thursday": [
        "alahamisi",
        "alh"
    ],
    "friday": [
        "ijumaa",
        "iju"
    ],
    "saturday": [
        "jumamosi",
        "jmo"
    ],
    "sunday": [
        "mulungu",
        "mul"
    ],
    "am": [
        "lwamilawu"
    ],
    "pm": [
        "pashamihe"
    ],
    "year": [
        "mwakha"
    ],
    "month": [
        "mwesi"
    ],
    "week": [
        "ilijuma"
    ],
    "day": [
        "lusiku"
    ],
    "hour": [
        "ilisala"
    ],
    "minute": [
        "idakika"
    ],
    "second": [
        "isekunde"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "imehe"
        ],
        "0 day ago": [
            "ineng'uni"
        ],
        "in 1 day": [
            "pamulaawu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "zu",
    "date_order": "MDY",
    "january": [
        "januwari",
        "jan",
        "umasingana"
    ],
    "february": [
        "februwari",
        "feb"
    ],
    "march": [
        "mashi",
        "mas"
    ],
    "april": [
        "ephreli",
        "eph"
    ],
    "may": [
        "meyi",
        "mey"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "julayi",
        "jul"
    ],
    "august": [
        "agasti",
        "aga"
    ],
    "september": [
        "septhemba",
        "sep"
    ],
    "october": [
        "okthoba",
        "okt"
    ],
    "november": [
        "novemba",
        "nov"
    ],
    "december": [
        "disemba",
        "dis"
    ],
    "monday": [
        "umsombuluko",
        "mso"
    ],
    "tuesday": [
        "ulwesibili",
        "bil"
    ],
    "wednesday": [
        "ulwesithathu",
        "tha"
    ],
    "thursday": [
        "ulwesine",
        "sin"
    ],
    "friday": [
        "ulwesihlanu",
        "hla"
    ],
    "saturday": [
        "umgqibelo",
        "mgq"
    ],
    "sunday": [
        "isonto",
        "son"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "unyaka"
    ],
    "month": [
        "inyanga"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "usuku"
    ],
    "hour": [
        "ihora"
    ],
    "minute": [
        "iminithi"
    ],
    "second": [
        "isekhondi"
    ],
    "relative-type": {
        "1 year ago": [
            "onyakeni odlule"
        ],
        "0 year ago": [
            "kulo nyaka"
        ],
        "in 1 year": [
            "unyaka ozayo"
        ],
        "1 month ago": [
            "inyanga edlule"
        ],
        "0 month ago": [
            "le nyanga"
        ],
        "in 1 month": [
            "inyanga ezayo"
        ],
        "1 week ago": [
            "iviki eledlule"
        ],
        "0 week ago": [
            "leli viki"
        ],
        "in 1 week": [
            "iviki elizayo"
        ],
        "1 day ago": [
            "izolo"
        ],
        "0 day ago": [
            "namhlanje"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "0 hour ago": [
            "leli hora"
        ],
        "0 minute ago": [
            "leli minithi"
        ],
        "0 second ago": [
            "manje"
        ]
    },
    "relative-type-regex": {
        "\\1 year ago": [
            "(\\d+) unyaka odlule",
            "(\\d+) iminyaka edlule"
        ],
        "\\1 month ago": [
            "(\\d+) inyanga edlule",
            "(\\d+) izinyanga ezedlule"
        ],
        "\\1 day ago": [
            "(\\d+) usuku olwedlule",
            "(\\d+) izinsuku ezedlule"
        ],
        "\\1 hour ago": [
            "(\\d+) ihora eledlule",
            "(\\d+) amahora edlule"
        ],
        "\\1 minute ago": [
            "(\\d+) iminithi eledlule",
            "(\\d+) amaminithi edlule"
        ],
        "\\1 second ago": [
            "(\\d+) isekhondi eledlule",
            "(\\d+) amasekhondi edlule"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "pt",
    "date_order": "DMY",
    "january": [
        "janeiro",
        "jan"
    ],
    "february": [
        "fevereiro",
        "fev"
    ],
    "march": [
        "março",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maio",
        "mai"
    ],
    "june": [
        "junho",
        "jun"
    ],
    "july": [
        "julho",
        "jul"
    ],
    "august": [
        "agosto",
        "ago"
    ],
    "september": [
        "setembro",
        "set",
        "Septembro"
    ],
    "october": [
        "outubro",
        "out"
    ],
    "november": [
        "novembro",
        "nov"
    ],
    "december": [
        "dezembro",
        "dez"
    ],
    "monday": [
        "segunda-feira",
        "seg",
        "Segunda"
    ],
    "tuesday": [
        "terça-feira",
        "ter",
        "Terça"
    ],
    "wednesday": [
        "quarta-feira",
        "qua",
        "Quarta"
    ],
    "thursday": [
        "quinta-feira",
        "qui",
        "Quinta"
    ],
    "friday": [
        "sexta-feira",
        "sex",
        "Sexta"
    ],
    "saturday": [
        "sábado",
        "sáb",
        "Sab"
    ],
    "sunday": [
        "domingo",
        "dom"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ano",
        "anos"
    ],
    "month": [
        "mês",
        "meses"
    ],
    "week": [
        "semana",
        "sem",
        "semanas"
    ],
    "day": [
        "dia",
        "dias"
    ],
    "hour": [
        "hora",
        "h",
        "horas"
    ],
    "minute": [
        "minuto",
        "min",
        "m",
        "minutos"
    ],
    "second": [
        "segundo",
        "seg",
        "s",
        "segundos"
    ],
    "relative-type": {
        "1 year ago": [
            "ano passado"
        ],
        "0 year ago": [
            "este ano"
        ],
        "in 1 year": [
            "próximo ano"
        ],
        "1 month ago": [
            "mês passado"
        ],
        "0 month ago": [
            "este mês"
        ],
        "in 1 month": [
            "próximo mês"
        ],
        "1 week ago": [
            "semana passada"
        ],
        "0 week ago": [
            "esta semana"
        ],
        "in 1 week": [
            "próxima semana"
        ],
        "1 day ago": [
            "ontem"
        ],
        "0 day ago": [
            "hoje"
        ],
        "in 1 day": [
            "amanhã"
        ],
        "0 hour ago": [
            "esta hora"
        ],
        "0 minute ago": [
            "este minuto"
        ],
        "0 second ago": [
            "agora"
        ],
        "2 day ago": [
            "anteontem"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "em (\\d+) ano",
            "em (\\d+) anos"
        ],
        "\\1 year ago": [
            "há (\\d+) ano",
            "há (\\d+) anos"
        ],
        "in \\1 month": [
            "em (\\d+) mês",
            "em (\\d+) meses"
        ],
        "\\1 month ago": [
            "há (\\d+) mês",
            "há (\\d+) meses"
        ],
        "in \\1 week": [
            "em (\\d+) semana",
            "em (\\d+) semanas",
            "em (\\d+) sem"
        ],
        "\\1 week ago": [
            "há (\\d+) semana",
            "há (\\d+) semanas",
            "há (\\d+) sem"
        ],
        "in \\1 day": [
            "em (\\d+) dia",
            "em (\\d+) dias"
        ],
        "\\1 day ago": [
            "há (\\d+) dia",
            "há (\\d+) dias"
        ],
        "in \\1 hour": [
            "em (\\d+) hora",
            "em (\\d+) horas",
            "em (\\d+) h"
        ],
        "\\1 hour ago": [
            "há (\\d+) hora",
            "há (\\d+) horas",
            "há (\\d+) h"
        ],
        "in \\1 minute": [
            "em (\\d+) minuto",
            "em (\\d+) minutos",
            "em (\\d+) min",
            "em (\\d+) mins"
        ],
        "\\1 minute ago": [
            "há (\\d+) minuto",
            "há (\\d+) minutos",
            "há (\\d+) min",
            "há (\\d+) mins"
        ],
        "in \\1 second": [
            "em (\\d+) segundo",
            "em (\\d+) segundos",
            "em (\\d+) seg",
            "em (\\d+) segs"
        ],
        "\\1 second ago": [
            "há (\\d+) segundo",
            "há (\\d+) segundos",
            "há (\\d+) seg"
        ]
    },
    "locale_specific": {
        "pt-CH": {
            "name": "pt-CH",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-GW": {
            "name": "pt-GW",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-MZ": {
            "name": "pt-MZ",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-CV": {
            "name": "pt-CV",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-LU": {
            "name": "pt-LU",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-MO": {
            "name": "pt-MO",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-GQ": {
            "name": "pt-GQ",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-ST": {
            "name": "pt-ST",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-PT": {
            "name": "pt-PT",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-AO": {
            "name": "pt-AO",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        },
        "pt-TL": {
            "name": "pt-TL",
            "monday": [
                "segunda"
            ],
            "tuesday": [
                "terça"
            ],
            "wednesday": [
                "quarta"
            ],
            "thursday": [
                "quinta"
            ],
            "friday": [
                "sexta"
            ],
            "am": [
                "manhã",
                "da manhã"
            ],
            "pm": [
                "tarde",
                "da tarde"
            ],
            "relative-type-regex": {
                "in \\1 year": [
                    "dentro de (\\d+) ano",
                    "dentro de (\\d+) anos"
                ],
                "in \\1 month": [
                    "dentro de (\\d+) meses",
                    "dentro de (\\d+) mês"
                ],
                "in \\1 week": [
                    "dentro de (\\d+) sem",
                    "dentro de (\\d+) semana",
                    "dentro de (\\d+) semanas"
                ],
                "in \\1 day": [
                    "dentro de (\\d+) dias",
                    "dentro de (\\d+) dia"
                ],
                "in \\1 hour": [
                    "dentro de (\\d+) h",
                    "dentro de (\\d+) hora",
                    "dentro de (\\d+) horas"
                ],
                "in \\1 minute": [
                    "dentro de (\\d+) min",
                    "dentro de (\\d+) minuto",
                    "dentro de (\\d+) minutos"
                ],
                "in \\1 second": [
                    "dentro de (\\d+) segundo",
                    "dentro de (\\d+) segundos",
                    "dentro de (\\d+) s"
                ],
                "\\1 second ago": [
                    "há (\\d+) s"
                ]
            }
        }
    },
    "skip": [
        "de",
        "cerca",
        "e",
        "às",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "pertain": [
        "de"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "atrás",
        "há"
    ],
    "in": [
        "em"
    ],
    "simplifications": [
        {
            "uma": "1"
        },
        {
            "um": "1"
        },
        {
            "alguns segundos": "44 segundos"
        }
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "sg",
    "date_order": "DMY",
    "january": [
        "nyenye",
        "nye"
    ],
    "february": [
        "fulundïgi",
        "ful"
    ],
    "march": [
        "mbängü",
        "mbä"
    ],
    "april": [
        "ngubùe",
        "ngu"
    ],
    "may": [
        "bêläwü",
        "bêl"
    ],
    "june": [
        "föndo",
        "fön"
    ],
    "july": [
        "lengua",
        "len"
    ],
    "august": [
        "kükürü",
        "kük"
    ],
    "september": [
        "mvuka",
        "mvu"
    ],
    "october": [
        "ngberere",
        "ngb"
    ],
    "november": [
        "nabändüru",
        "nab"
    ],
    "december": [
        "kakauka",
        "kak"
    ],
    "monday": [
        "bïkua-ûse",
        "bk2"
    ],
    "tuesday": [
        "bïkua-ptâ",
        "bk3"
    ],
    "wednesday": [
        "bïkua-usïö",
        "bk4"
    ],
    "thursday": [
        "bïkua-okü",
        "bk5"
    ],
    "friday": [
        "lâpôsö",
        "lâp"
    ],
    "saturday": [
        "lâyenga",
        "lây"
    ],
    "sunday": [
        "bikua-ôko",
        "bk1"
    ],
    "am": [
        "nd"
    ],
    "pm": [
        "lk"
    ],
    "year": [
        "ngû"
    ],
    "month": [
        "nze"
    ],
    "week": [
        "dimâsi"
    ],
    "day": [
        "lâ"
    ],
    "hour": [
        "ngbonga"
    ],
    "minute": [
        "ndurü ngbonga"
    ],
    "second": [
        "nzîna ngbonga"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "bîrï"
        ],
        "0 day ago": [
            "lâsô"
        ],
        "in 1 day": [
            "kêkerêke"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "hy",
    "date_order": "DMY",
    "january": [
        "հունվար",
        "հնվ",
        "հունվարի"
    ],
    "february": [
        "փետրվար",
        "փտվ",
        "փետրվարի"
    ],
    "march": [
        "մարտ",
        "մրտ",
        "մարտի"
    ],
    "april": [
        "ապրիլ",
        "ապր",
        "ապրիլի"
    ],
    "may": [
        "մայիս",
        "մյս",
        "մայիսի"
    ],
    "june": [
        "հունիս",
        "հնս",
        "հունիսի"
    ],
    "july": [
        "հուլիս",
        "հլս",
        "հուլիսի"
    ],
    "august": [
        "օգոստոս",
        "օգս",
        "օգոստոսի"
    ],
    "september": [
        "սեպտեմբեր",
        "սեպ",
        "սեպտեմբերի"
    ],
    "october": [
        "հոկտեմբեր",
        "հոկ",
        "հոկտեմբերի"
    ],
    "november": [
        "նոյեմբեր",
        "նոյ",
        "նոյեմբերի"
    ],
    "december": [
        "դեկտեմբեր",
        "դեկ",
        "դեկտեմբերի"
    ],
    "monday": [
        "երկուշաբթի",
        "երկ"
    ],
    "tuesday": [
        "երեքշաբթի",
        "երք"
    ],
    "wednesday": [
        "չորեքշաբթի",
        "չրք"
    ],
    "thursday": [
        "հինգշաբթի",
        "հնգ"
    ],
    "friday": [
        "ուրբաթ",
        "ուր"
    ],
    "saturday": [
        "շաբաթ",
        "շբթ"
    ],
    "sunday": [
        "կիրակի",
        "կիր"
    ],
    "am": [
        "am",
        "կա"
    ],
    "pm": [
        "pm",
        "կհ"
    ],
    "year": [
        "տարի",
        "տ"
    ],
    "month": [
        "ամիս",
        "ամս"
    ],
    "week": [
        "շաբաթ",
        "շաբ"
    ],
    "day": [
        "օր"
    ],
    "hour": [
        "ժամ",
        "ժ"
    ],
    "minute": [
        "րոպե",
        "ր"
    ],
    "second": [
        "վայրկյան",
        "վ"
    ],
    "relative-type": {
        "1 year ago": [
            "նախորդ տարի"
        ],
        "0 year ago": [
            "այս տարի"
        ],
        "in 1 year": [
            "հաջորդ տարի"
        ],
        "1 month ago": [
            "նախորդ ամիս",
            "անցյալ ամիս"
        ],
        "0 month ago": [
            "այս ամիս"
        ],
        "in 1 month": [
            "հաջորդ ամիս"
        ],
        "1 week ago": [
            "նախորդ շաբաթ"
        ],
        "0 week ago": [
            "այս շաբաթ"
        ],
        "in 1 week": [
            "հաջորդ շաբաթ"
        ],
        "1 day ago": [
            "երեկ"
        ],
        "0 day ago": [
            "այսօր"
        ],
        "in 1 day": [
            "վաղը"
        ],
        "0 hour ago": [
            "այս ժամին"
        ],
        "0 minute ago": [
            "այս րոպեին"
        ],
        "0 second ago": [
            "այժմ"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) տարուց"
        ],
        "\\1 year ago": [
            "(\\d+) տարի առաջ",
            "(\\d+) տ առաջ"
        ],
        "in \\1 month": [
            "(\\d+) ամսից"
        ],
        "\\1 month ago": [
            "(\\d+) ամիս առաջ"
        ],
        "in \\1 week": [
            "(\\d+) շաբաթից",
            "(\\d+) շաբ-ից",
            "(\\d+) շաբ անց"
        ],
        "\\1 week ago": [
            "(\\d+) շաբաթ առաջ",
            "(\\d+) շաբ առաջ"
        ],
        "in \\1 day": [
            "(\\d+) օրից"
        ],
        "\\1 day ago": [
            "(\\d+) օր առաջ"
        ],
        "in \\1 hour": [
            "(\\d+) ժամից",
            "(\\d+) ժ-ից"
        ],
        "\\1 hour ago": [
            "(\\d+) ժամ առաջ",
            "(\\d+) ժ առաջ"
        ],
        "in \\1 minute": [
            "(\\d+) րոպեից",
            "(\\d+) ր-ից"
        ],
        "\\1 minute ago": [
            "(\\d+) րոպե առաջ",
            "(\\d+) ր առաջ"
        ],
        "in \\1 second": [
            "(\\d+) վայրկյանից",
            "(\\d+) վրկ-ից",
            "(\\d+) վ-ից"
        ],
        "\\1 second ago": [
            "(\\d+) վայրկյան առաջ",
            "(\\d+) վրկ առաջ",
            "(\\d+) վ առաջ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "fil",
    "date_order": "MDY",
    "january": [
        "enero",
        "ene"
    ],
    "february": [
        "pebrero",
        "peb"
    ],
    "march": [
        "marso",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "mayo",
        "may"
    ],
    "june": [
        "hunyo",
        "hun"
    ],
    "july": [
        "hulyo",
        "hul"
    ],
    "august": [
        "agosto",
        "ago"
    ],
    "september": [
        "setyembre",
        "set"
    ],
    "october": [
        "oktubre",
        "okt"
    ],
    "november": [
        "nobyembre",
        "nob"
    ],
    "december": [
        "disyembre",
        "dis"
    ],
    "monday": [
        "lunes",
        "lun"
    ],
    "tuesday": [
        "martes",
        "mar"
    ],
    "wednesday": [
        "miyerkules",
        "miy"
    ],
    "thursday": [
        "huwebes",
        "huw"
    ],
    "friday": [
        "biyernes",
        "biy"
    ],
    "saturday": [
        "sabado",
        "sab"
    ],
    "sunday": [
        "linggo",
        "lin"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "taon"
    ],
    "month": [
        "buwan"
    ],
    "week": [
        "linggo"
    ],
    "day": [
        "araw"
    ],
    "hour": [
        "oras"
    ],
    "minute": [
        "minuto",
        "min"
    ],
    "second": [
        "segundo",
        "seg"
    ],
    "relative-type": {
        "1 year ago": [
            "nakaraang taon"
        ],
        "0 year ago": [
            "ngayong taon"
        ],
        "in 1 year": [
            "susunod na taon"
        ],
        "1 month ago": [
            "nakaraang buwan"
        ],
        "0 month ago": [
            "ngayong buwan"
        ],
        "in 1 month": [
            "susunod na buwan"
        ],
        "1 week ago": [
            "nakalipas na linggo",
            "nakaraang linggo"
        ],
        "0 week ago": [
            "sa linggong ito",
            "ngayong linggo"
        ],
        "in 1 week": [
            "susunod na linggo"
        ],
        "1 day ago": [
            "kahapon"
        ],
        "0 day ago": [
            "ngayong araw"
        ],
        "in 1 day": [
            "bukas"
        ],
        "0 hour ago": [
            "ngayong oras"
        ],
        "0 minute ago": [
            "sa minutong ito"
        ],
        "0 second ago": [
            "ngayon"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "sa (\\d+) taon"
        ],
        "\\1 year ago": [
            "(\\d+) taon ang nakalipas"
        ],
        "in \\1 month": [
            "sa (\\d+) buwan"
        ],
        "\\1 month ago": [
            "(\\d+) buwan ang nakalipas"
        ],
        "in \\1 week": [
            "sa (\\d+) linggo"
        ],
        "\\1 week ago": [
            "(\\d+) linggo ang nakalipas"
        ],
        "in \\1 day": [
            "sa (\\d+) araw"
        ],
        "\\1 day ago": [
            "(\\d+) araw ang nakalipas"
        ],
        "in \\1 hour": [
            "sa (\\d+) oras"
        ],
        "\\1 hour ago": [
            "(\\d+) oras ang nakalipas",
            "(\\d+) oras nakalipas"
        ],
        "in \\1 minute": [
            "sa (\\d+) minuto",
            "sa (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) minuto ang nakalipas",
            "(\\d+) min ang nakalipas"
        ],
        "in \\1 second": [
            "sa (\\d+) segundo",
            "sa (\\d+) seg"
        ],
        "\\1 second ago": [
            "(\\d+) segundo ang nakalipas",
            "(\\d+) seg ang nakalipas",
            "(\\d+) seg nakalipas"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
